# Copyright 2018 ICON Foundation
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import os
import signal
from typing import Optional

from iconcommons import Logger


def earlgrey_close(func: str, exc: Optional[BaseException]):
    Logger.error(tag="MQ", msg=f"[{func}] connection closed. {exc}")
    os.killpg(0, signal.SIGKILL)
